library(sp)
library(raster)

### Estimate range size of moss species (Area of Occupancy, 2 x 2 km) ###

# Specify the folder containing CSV files
folder_path <- "Moss coords/CSVs"

# Get a list of CSV files in the folder
csv_files <- list.files(folder_path, pattern = ".csv", full.names = TRUE)

# Initialize an empty dataframe to store results
result_df <- data.frame(Species = character(), AOO = numeric())


for (csv_file in csv_files) {
  
  sp_data <- read.csv(csv_file)
  
  # Check if the species has only one record, if so, add it to the result dataframe and skip the processing
  if (nrow(sp_data) == 1) {
    species_name <- basename(tools::file_path_sans_ext(csv_file))
    cat("Skipping species with only one record:", species_name, "\n")
    result_df <- rbind(result_df, data.frame(Species = species_name, AOO = NA))
    next  # Skip to the next iteration of the loop
  }
  
  coordinates(sp_data) <- c("LONG", "LAT")
  
  # Set the coordinate reference system to WGS84 (EPSG:4326)
  proj4string(sp_data) <- CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0")
  
  # Transform to Antarctic Polar Stereographic projection (EPSG:3031)
  sp_data <- spTransform(sp_data, CRS("+proj=stere +lat_0=-90 +lat_ts=-71 +lon_0=0 +k=1 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs"))
  
  # Create a 2x2 km grid
  grid <- raster(extent(sp_data), res = c(2000, 2000))
  projection(grid) <- CRS("+proj=stere +lat_0=-90 +lon_0=0 +lat_ts=-71 +a=6378273 +b=6356889.449 +units=m +no_defs")
  
  # Assign species presence to grid cells
  presence_grid <- rasterize(sp_data, grid, field = 1)
  
  # Calculate Area of Occupancy
  aoo <- cellStats(presence_grid, sum)
  
  # Append results to the dataframe
  result_df <- rbind(result_df, data.frame(Species = basename(tools::file_path_sans_ext(csv_file)), AOO = aoo))
}

# Replace NA values with 1 in the "AOO" column
result_df$AOO <- ifelse(is.na(result_df$AOO), 1, result_df$AOO)

# Multiply the entire "AOO" column by 4
result_df$AOO <- result_df$AOO * 4

result_df$n_records <-  result_df$AOO/4

print(result_df)

# final dataframe
moss_AN <- result_df

hist(moss_AN$AOO)


# plot
(range <- ggplot(moss_AN, aes(x = AOO)) +
        geom_histogram(binwidth = 50, 
                       fill = "forestgreen", 
                       color = "black", alpha = 0.5) +
        theme_classic() +
        ylim(0, 25) +
        labs(x = expression("Range size (km"^2*")"),
             y = "Frequency")  +
        theme(axis.line = element_line(color = "black"),
              axis.text = element_text(color = "black", size = 11),
              axis.title = element_text(size = 13)))
  


# skewness
library(moments)

moments::skewness(moss_AN$AOO)
kurtosis(moss_AN$AOO)
jarque.test(moss_AN$AOO)

# range sizes summary
moss_AN %>%
  mutate(range_group = case_when(
    AOO < 10 ~ "< 10 km2",
    AOO < 100 ~ "10-100 km2",
    AOO > 500 ~ "> 500 km2",
    TRUE ~ "100-500 km2"
  )) %>%
  group_by(range_group) %>%
  summarise(num_species = n())
