library(vegan)
library(ape)
library(ggplot2)
library(viridis)
library(cowplot)
library(betapart)
library(ggrepel)
library(dplyr)
library(qpcR)

moss_acbr <- read.csv("species_presence_matrix_ACBR.csv", row.names = 1)

#reorder columns - ACBR
col.order <- c("X1","X2","X3","X4","X5", "X6", "X7", "X8", "X9", "X10", "X11", "X12", "X13", "X14", "X15", "X16")
moss_acbr <- moss_acbr[ , col.order]

# rename columns

biogeographic_regions <- c(
  "North-east Antarctic Peninsula", "South Orkney Islands", "North-west Antarctic Peninsula", 
  "Central South Antarctic Peninsula","Enderby Land", "Dronning Maud Land", "East Antarctica", 
  "North Victoria Land", "South Victoria Land", "Transantarctic Mountains", "Ellsworth Mountains", 
  "Marie Byrd Land", "Adelie Land", "Ellsworth Land", "South Antarctic Peninsula", "Prince Charles Mountains"
)

colnames(moss_acbr) <- biogeographic_regions

## -- Calculate richness -- ##

moss_acbr_sp <- t(moss_acbr)

(aspa_species_richness <- data.frame(
  ASPA_No = rownames(moss_acbr_sp),
  SpeciesRichness = rowSums(moss_acbr_sp[, -1])
))

proportions <- aspa_species_richness %>%
  mutate(Proportion = SpeciesRichness / 109)

ggplot(aspa_species_richness, aes(x = ASPA_No, y = SpeciesRichness, fill = ASPA_No)) +
  geom_bar(stat = "identity") +
  theme_minimal() +
  scale_fill_viridis(discrete = TRUE) +
  labs(x = "Region", y = "Number of Species", title = "Number of Species per Antarctic Specially Protected Area") +
  theme(legend.position = "none",
        axis.text.x = element_text(angle = 45, hjust = 1, size = 7))

## Diversity indexes ##

# Transpose the presence-absence matrix
sites_species_matrix <- t(moss_acbr)

# Calculate proportions of species in each site
proportions <- sites_species_matrix / rowSums(sites_species_matrix)

# Calculate Simpson's Diversity Index for each site
simpson_diversity <- diversity(proportions, index = "simpson")

# Calculate Inverse Simpson's Diversity Index for each site
inverse_simpson_diversity <- diversity(proportions, index = "invsimpson")

# Calculate Shannon's Diversity Index for each site
shannon_diversity <- diversity(proportions, index = "shannon")

# Create a data frame to store the results
diversity_indices_df_acbr <- data.frame(
  ASPA_No = colnames(moss_acbr),
  Simpson_Diversity = simpson_diversity,
  Inverse_Simpson_Diversity = inverse_simpson_diversity,
  Shannon_Diversity = shannon_diversity
)

diversity_indices_df_acbr

acbr <- na.omit(diversity_indices_df_acbr)

# Plot diversity across sites
(plot.shan <- ggplot(diversity_indices_df_aspa, aes(x = ASPA_No, y = Shannon_Diversity, color = ASPA_No)) +
    geom_point(size = 3) +
    scale_color_viridis_d(option = "magma", begin = 0.2, end = 0.8) +
    ylab("Shannon's H'") + 
    xlab("") +
    theme_bw() +
    theme(legend.position = "none",
          axis.text.x = element_text(angle = 90, hjust = 1, vjust = 0.4)))


## -- Beta diversity -- ##


# prepare data

# Transpose the presence-absence matrix
sites_species_matrix <- t(moss_acbr)

# Remove empty rows (sites with all zeros)
non_empty_sites <- rowSums(sites_species_matrix) > 0
sites_species_matrix_non_empty <- sites_species_matrix[non_empty_sites, ]

# Remove columns with missing values (or apply imputation as needed)
sites_species_matrix_cleaned <- na.omit(sites_species_matrix_non_empty)

## Calculate dissimilarity ##

# Jaccard dissimilarity #

# Calculate Bray-Curtis dissimilarity between sites
dis_jac <- vegdist(sites_species_matrix_cleaned, method="jaccard", binary = T)

# Apply hierarchical clustering
hclust_jac <- hclust(dis_jac, method = "complete")

# Create a dendrogram plot
plot(hclust_jac, main = "Cluster Dendrogram")

#### NMDS ####

nmds <-
  metaMDS(sites_species_matrix_cleaned,
          distance = "jaccard",
          k = 3,
          maxit = 999, 
          trymax = 500,
          wascores = TRUE)

goodness(nmds) # Produces a results of test statistics for goodness of fit for each point

stressplot(nmds) # Produces a Shepards diagram

plot(nmds, "sites")   # Produces distance 
orditorp(nmds, "sites")   # Gives points labels

species_scores <- scores(nmds, display = "species")
ordiplot(nmds, display = "species")

fort <- fortify(nmds)
fort$group <- c(acbr$Group, rep(NA, nrow(fort) - length(acbr$Group)))

ggplot() +
  geom_point(data = subset(fort, score == 'sites'),
             mapping = aes(x = NMDS1, y = NMDS2, colour = factor(group)),
             #colour = "black",
             size = 4,
             alpha = 0.7) +
  geom_segment(data = subset(fort, score == 'species'),
               mapping = aes(x = 0, y = 0, xend = NMDS1, yend = NMDS2),
               arrow = arrow(length = unit(0.015, "npc")),
               colour = "darkgrey",
               size = 0.25, alpha = 0.5) +
  geom_abline(intercept = 0, slope = 0, linetype = "dashed", size = 0.8, colour = "gray") +
  geom_text(data = subset(fort, score == "sites"),
            mapping = aes(label = label, x = NMDS1 * 1.1, y = NMDS2 * 1.1),
            size = 2) +
  geom_vline(aes(xintercept = 0), linetype = "dashed", size = 0.8, colour = "gray") +
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.line = element_line(colour = "black"),
        legend.position = "none",
        aspect.ratio = 0.8) +
  ylim(-2, 2) + xlim(-2,2) +
  scale_color_brewer(palette = "Set1")

acbr <- read.csv("acbr.csv")


anosim(dis_jac, acbr$Group, permutations = 1000)

#adonis2(dis_jac ~ Group, data = acbr, permutations = 1000)
#disp.age = betadisper(dis_jac, acbr$Group)
#permutest(disp.age, pairwise=TRUE, permutations=1000)


## Turnover and nestedness components of beta diversity ##

# Calculate beta diversity components

beta_div_multi <- beta.multi(sites_species_matrix_cleaned, index.family="jaccard")

beta_div_multi

## Alpha, beta, and gamma Diversity per site ##

contribdiv(sites_species_matrix_cleaned, "richness")

## Relative contribution
(cd1 <- contribdiv(sites_species_matrix_cleaned, "richness", relative = TRUE, scaled = FALSE))

## Differentiation coefficients
attr(cd1, "diff.coef") # D_ST

## Zeta diversity ##

library(zetadiv)

(zeta.acbr <- zetadiv::Zeta.decline.ex(
  sites_species_matrix_cleaned,
  orders = 1:5))

frame.z.acbr <- data.frame(values = zeta.acbr$zeta.val, orders = zeta.acbr$zeta.order,
                           sd = zeta.acbr$zeta.val.sd)

(z.acbr <- ggplot(frame.z.acbr, aes(y = values, x = orders)) +
    geom_ribbon(aes(ymin = values-sd, ymax = values+sd),
                alpha = 0.2, fill = "forestgreen") +
    geom_line(colour = "forestgreen", size = 1) +
    geom_point(colour = "forestgreen", size = 2) +
    #ylim(-5,5) +
    theme_classic() +
    theme(aspect.ratio = 0.9) +
    scale_x_continuous(breaks = seq(min(frame.z.acbr$orders), max(frame.z.acbr$orders), by = 1),
                       labels = seq(min(frame.z.acbr$orders), max(frame.z.acbr$orders), by = 1))
  
)


## exponential vs power-law

aaa <- data.frame(values = round(zeta.acbr$zeta.val), orders = zeta.acbr$zeta.order)

# Fit exponential model
fit1 <- lm(log(aaa$values) ~ aaa$orders)

exp_model <- nls(values ~ a * exp(b * orders), 
                 data = aaa,
                 start = list(a = exp(coef(fit1)[1]), b = coef(fit1)[2]))

summary(exp_model)
plot(values ~ orders, data = aaa)
curve(predict(exp_model, newdata = data.frame(orders = x)), add = TRUE)

# Fit power-law model

fit2 <- lm(log(aaa$values)~ log(aaa$orders))

m <- nls(values ~ a*(orders^b), aaa, 
         start = list(a = exp(coef(fit2)[1]), b = coef(fit2)[2])) 

summary(m)
plot(values ~ orders, data = aaa)
curve(predict(m, newdata = data.frame(orders = x)), add = TRUE)    

AICc(exp_model)
AICc(m)


(acbr.z <- ggplot(aaa, aes(x = orders, y = log(values))) +
    geom_point(fill = "forestgreen", size = 3, shape = 21) +
    geom_smooth(method = "nls", formula = y ~ a * exp(b * x),
                method.args = list(start = coef(exp_model)),
                se = FALSE, color = "forestgreen", size = 0.75,
                alpha = 0.7) +
    geom_smooth(method = "nls", formula = y ~ a * (x^b),
                method.args = list(start = coef(m)),
                se = FALSE, color = "forestgreen", 
                linetype = "dashed", size = 0.75,
                alpha = 0.7) +
    theme_classic() +
    ylim(0, 4) + xlim(1, 5) +
    theme(aspect.ratio = .8)) +
  labs(x = "Zeta orders",
       y = "Log (Zeta diversity)") +
  theme(axis.line = element_line(color = "black"),
        axis.text = element_text(color = "black", size = 11))



